class Extension:
    # predefined filetypes for fast use
    PDF = "pdf"
    # word
    DOC = "doc"
    DOT = "dot"
    WBK = "wbk"
    DOCX = "docx"
    DOTX = "dotx"
    DOTM = "dotm"
    DOCB = "docb"
    WLL = "wll"
    WWL = "wwl"
    # excel
    XLS = "xls"
    XLT = "xlt"
    XLM = "xlm"
    XLL_ = "xll_"
    XLA_ = "xla_"
    XLA5 = "xla5"
    XLA8 = "xla8"
    XLSX = "xlsx"
    XLSM = "xlsm"
    XLTS = "xltx"
    XLTM = "xltm"
    XLSB = "xlsb"
    XLA = "xla"
    XLAM = "xlam"
    XLL = "xll"
    XLW = "xlw"
    # powepoint
    PPT = "ppt"
    POT = "pot"
    PPS = "pps"
    PPA = "ppa"
    PPAM = "ppam"
    PPTX = "pptx"
    PPTM = "pptm"
    POTX = "potx"
    POTM = "potm"
    PPAM = "ppam"
    PPSX = "ppsx"
    PPSM = "ppsm"
    SLDX = "sldx"
    SLDM = "sldm"
    PA = "pa"
    # videos
    MOV = "mov"
    MP4 = "mp4"
    WMV = "wmv"
    AVI = "avi"
    AVCHD = "avchd"
    FLV = "flv"
    F4V = "f4v"
    SWF = "swf"
    MKV = "mkv"
    WEBM = "webm"
    OGG = "ogg"
    OGV = "ogv"
    MPG = "mpg"
    AAC = "aac"
    WMA = "wma"
    # images
    JPG = "jpg"
    JPEG = "jpeg"
    JIFF = "jiff"
    PJPEG = "pjpeg"
    PJP = "pjp"
    PNG = "png"
    SVG = "svg"
    WEBP = "webp"
    GIF = "gif"
    BMP = "bmp"
    ICO = "ico"
    CUR = "cur"
    TIF = "tif"
    TIFF = "tiff"
    AVIF = "avif"
    APNG = "apng"

    ENV = "env"
    # lists
    LIST_IMAGE = [JPG, JPEG, JIFF, PJPEG, PJP, PNG, SVG, WEBP, GIF, BMP, ICO, CUR, TIF, TIFF, AVIF, APNG]
    LIST_VIDEO = [MOV, MP4, WMV, AVI, AVCHD, FLV, F4V, SWF, MKV, WEBM, OGG, OGV, MPG, AAC, WMA]
    LIST_POWERPOINT = [PPT, POT, PPS, PPA, PPAM, PPTX, PPTM, POTX, POTM, PPAM, PPSX, PPSM, SLDX, SLDM, PA]
    LIST_EXCEL = [XLS, XLT, XLM, XLL_, XLA_, XLA5, XLA8, XLSX, XLSM, XLTS, XLSB, XLA, XLAM, XLL, XLW]
    LIST_WORD = [DOC, DOT, WBK, DOCX, DOTX, DOTM, DOCB, WLL, WWL]